@@ -1,4 +1,5 @@
 pub const HAS_FEATURE: bool = cfg!(any(
+    feature = "22_0",
     feature = "0_21_1",
     feature = "0_21_0",
     feature = "0_20_1",
@@ -11,6 +12,7 @@ pub const HAS_FEATURE: bool = cfg!(any(
 ));
 
 #[cfg(not(any(
+    feature = "22_0",
     feature = "0_21_1",
     feature = "0_21_0",
     feature = "0_20_1",
@@ -23,6 +25,9 @@ pub const HAS_FEATURE: bool = cfg!(any(
 )))]
 pub const VERSION: &str = "N/A";
 
+#[cfg(feature = "22_0")]
+pub const VERSION: &str = "22.0";
+
 #[cfg(feature = "0_21_1")]
 pub const VERSION: &str = "0.21.1";
 
